@@ -1,5 +1,5 @@
 /* This file is part of Metaproxy.
-   Copyright (C) 2005-2013 Index Data
+   Copyright (C) Index Data
 
 Metaproxy is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
@@ -76,8 +76,7 @@ namespace metaproxy_1 {
                                        metaproxy_1::odr &odr_en,
                                        Z_SRW_PDU *sru_pdu_res,
                                        Z_SOAP **soap,
-                                       char *charset,
-                                       char *stylesheet);
+                                       char *charset);
 
         bool check_sru_query_exists(metaproxy_1::Package &package,
                                     metaproxy_1::odr &odr_en,
